@@ -26,7 +26,7 @@ def test_xlib_wm():
 
 
 def test_fd_leak():
-	for _ in xrange(10):
+	for _ in range(10):
 		test_get_display_uuid()
 		logger.slog("test_fd_leak() sleeping for 10 seconds")
 		time.sleep(10);
