@@ -13,24 +13,24 @@ from winswitch.util.simple_logger import set_loggers_debug
 set_loggers_debug(True)
 
 class TestReload:
-	
+
 	PERSIST = ["str", "int", "list"]
-	
+
 	def __init__(self):
 		self.str = "hello"
 		self.int = 1
 		self.list  = ["l1", "l2", "l3"]
 
 try:
-	file = "/tmp/props.txt"
+	filename = "/tmp/props.txt"
 	test = TestReload()
 	test.str="modstr"
 	test.int=2
 	test.list = ["m1", "m2"]
-	save_object_to_properties(file, test)
+	save_object_to_properties(filename, test)
+
+	reloaded = load_object_from_properties(filename, TestReload)
 
-	reloaded = load_object_from_properties(file, TestReload)
-	
 	for field in get_persist(test):
 		print "testing '%s'" % field
 		original = getattr(test, field)
@@ -39,4 +39,4 @@ try:
 
 except Exception, e:
 	print 'file_io_test Caught exception: %s: %s' % (e.__class__, e)
-	traceback.print_exc()
\ No newline at end of file
+	traceback.print_exc()
