@@ -227,6 +227,9 @@ else:
 						# those two are also listed in workarounds, but I can't get them to run reliably:
 						"gnome-terminal",
 						"mate-terminal",
+						#special applications:
+						#msjnc = http://mad-scientist.us/juniper.html, daemonizes..
+						"msjnc",
 						""]
 	DEFAULT_IGNORED_XSESSIONS = [
 							#Moblin requires GL, and none of the virtual desktop provide this extension
