@@ -514,7 +514,7 @@ def save_object_to_properties(filename, instance, keys=None, chmod=None):
 		os.chmod(filename, chmod)
 	set_object_stored_as_filename(instance, filename)
 
-def load_properties(filename):
+def load_properties(filename, clobber=True):
 	if not is_valid_file(filename):
 		logger.sdebug("is not a valid file!", filename)
 		return None
@@ -530,7 +530,8 @@ def load_properties(filename):
 		found = min( [ pos for pos in punctuation if pos != -1 ] )
 		name= propDef[:found].rstrip()
 		value= propDef[found:].lstrip(":= ").rstrip()
-		propDict[name]= value
+		if clobber or (name not in propDict):
+			propDict[name]= value
 	propFile.close()
 	return propDict
 
@@ -548,7 +549,7 @@ def save_properties(filename, props,
 		if key.startswith("#"):
 			propFile.write("%s\n" % key)			#comments
 			continue
-			
+
 		assert key in props.keys()
 		value = props.get(key)
 		value_type = type(value)
@@ -575,7 +576,7 @@ def save_properties(filename, props,
 			continue
 		propFile.write("%s=%s\n" % (key, value))
 	propFile.close()
-	
+
 
 def get_persist_dict(obj, keys_in=None):
 	keys = keys_in
