@@ -7,6 +7,8 @@
 import os.path
 import hashlib
 import re
+import ConfigParser
+
 from winswitch.util.which import which
 
 from winswitch.util.simple_logger import Logger, msig
@@ -17,7 +19,7 @@ debug_import = logger.get_debug_import()
 debug_import("common")
 from winswitch.util.common import csv_list, visible_command, load_binary_file, is_valid_file, delete_if_exists
 debug_import("file_io")
-from winswitch.util.file_io import get_menu_dir, get_xsessions_dir, get_actions_dir, load_properties, save_properties
+from winswitch.util.file_io import get_menu_dir, get_xsessions_dir, get_actions_dir, save_properties
 debug_import("paths")
 from winswitch.util.paths import XSESSION_DIRS, WINSWITCH_COMMAND_WRAPPER, PREFIX_SEARCH_ORDER
 debug_import("consts")
@@ -361,32 +363,47 @@ def load_menu_file(menu_dir, filename, req_cmd, ignored_commands=None, whitelist
 	sig = msig(menu_dir, filename, req_cmd, ignored_commands, whitelist_commands, ignored_in, skipped, disabled_categories, file_type)
 	short_sig = msig(menu_dir, filename, req_cmd, "[..]", "[..]")
 	full_path = os.path.join(menu_dir, filename)
-	desktop_info = load_properties(full_path)
-	if not desktop_info:
+	desktop_info = ConfigParser.ConfigParser()
+	if not desktop_info.read(full_path):
 		logger.debug(short_sig+" failed to load '%s'" % full_path)
 		return	None
 
 	enabled = True
-	no_display = desktop_info.get('NoDisplay')
-	if no_display and (no_display == "true" or no_display == "1"):
-		enabled = False
-
-	only_show_in = desktop_info.get('OnlyShowIn')
-	if only_show_in and len(only_show_in)>0:
-		shown_in = only_show_in.split(";")
-		ignored = True
-		for shown in shown_in:
-			if len(shown)>0 and shown not in ignored_in:
-				ignored = False
-				break
-		if ignored:
+	try:
+		no_display = desktop_info.get('Desktop Entry', 'NoDisplay')
+		if no_display and (no_display == "true" or no_display == "1"):
 			enabled = False
+	except ConfigParser.NoOptionError:
+		pass
+
+	try:
+		only_show_in = desktop_info.get('Desktop Entry', 'OnlyShowIn')
+		if only_show_in and len(only_show_in)>0:
+			shown_in = only_show_in.split(";")
+			ignored = True
+			for shown in shown_in:
+				if len(shown)>0 and shown not in ignored_in:
+					ignored = False
+					break
+			if ignored:
+				enabled = False
+	except ConfigParser.NoOptionError:
+		pass
+
+	try:
+		name = desktop_info.get('Desktop Entry', 'Name')
+	except ConfigParser.NoOptionError:
+		name = None
 
-	name = desktop_info.get('Name')
 	if not name or len(name)==0:
 		logger.debug(sig+" name is missing!")
 		return	None
-	cmd = desktop_info.get('Exec')
+
+	try:
+		cmd = desktop_info.get('Desktop Entry', 'Exec')
+	except ConfigParser.NoOptionError:
+		cmd = None
+
 	if req_cmd and (not cmd or len(cmd)==0):
 		return	None
 
@@ -426,9 +443,21 @@ def load_menu_file(menu_dir, filename, req_cmd, ignored_commands=None, whitelist
 			skipped.append(name)
 			enabled = False
 
-	comment = desktop_info.get('Comment')
-	icon_filename = desktop_info.get('Icon')
-	categories_list = desktop_info.get('Categories')
+	try:
+		comment = desktop_info.get('Desktop Entry', 'Comment')
+	except ConfigParser.NoOptionError:
+		comment = None
+
+	try:
+		icon_filename = desktop_info.get('Desktop Entry', 'Icon')
+	except ConfigParser.NoOptionError:
+		icon_filename = None
+
+	try:
+		categories_list = desktop_info.get('Desktop Entry', 'Categories')
+	except ConfigParser.NoOptionError:
+		categories_list = None
+
 	categories = []
 	uses_sound_out = matches_any(noparams, DEFAULT_SOUNDOUT_ENABLED_COMMANDS) is not None
 	uses_sound_in = matches_any(noparams, DEFAULT_SOUNDIN_ENABLED_COMMANDS) is not None
@@ -456,7 +485,7 @@ def load_menu_file(menu_dir, filename, req_cmd, ignored_commands=None, whitelist
 
 	names = {}
 	comments = {}
-	for key,value in desktop_info.items():
+	for key,value in desktop_info.items('Desktop Entry'):
 		_NAMEKEY='Name['
 		_COMMENTKEY="Comment["
 		_ENDKEY="]"
