@@ -113,7 +113,7 @@ def exec_nopipe(cmd, env=None, extra_env=None, wait=False, shell=False, cwd=None
 			env = os.environ.copy()
 		if extra_env:
 			for key, value in extra_env.items():
-				env[key] = value
+				env[str(key)] = str(value)
 		if WIN32:
 			process = subprocess.Popen(cmd, stdin=pipe, stdout=pipe, stderr=pipe, shell=shell, env=env, cwd=cwd,
 									creationflags=SUBPROCESS_CREATION_FLAGS)
