@@ -492,7 +492,12 @@ class	ServerUtilBase(DisplayUtil):
 		try:
 			shutil.rmtree(session_dir)
 		except Exception, e:
-			self.serr("failed to delete %s" % session_dir, e, session)
+			self.serror("failed to delete %s: %s - trying again" % (session_dir, e), session)
+			#this may succeed now, if the error was because of a race:
+			try:
+				shutil.rmtree(session_dir)
+			except Exception, e:
+				self.serr("failed to delete %s" % session_dir, e, session)
 		#now clear pulse
 		if session.pulse_address and session.pulse_address.startswith("unix:"):
 			socket = session.pulse_address[len("unix:"):]
@@ -608,7 +613,7 @@ class	ServerUtilBase(DisplayUtil):
 		if len(self.clean_prelaunch_failures())>=self.max_prelaunch_failures:
 			self.serr("too many prelaunch failures: %s - not starting any more" % len(self.prelaunch_failures), uuid, delay)
 			return
-		existing = self.get_prelaunch_session(None, uuid, None, {})
+		existing = self.get_prelaunch_session(uuid, None, None, {})
 		if not existing:
 			callLater(delay, self.may_start_prelaunch_session, uuid)
 		else:
@@ -860,6 +865,7 @@ class	ServerUtilBase(DisplayUtil):
 				""" Sets the session attributes - save will cause it to start """
 				self.prelaunch_start_command(session, server_command, user, screen_size, opts, filenames)
 				self.add_session(session)
+				self.save_session(session)
 				self.may_schedule_prelaunch(user.uuid, 5.0)		#in case we used up all the pre-launch
 				return	session
 
