@@ -227,6 +227,11 @@ class	XpraServerUtil(ServerUtilBase):
 			return	Session.STATUS_AVAILABLE
 		elif l.startswith("xpra is terminating."):
 			return	Session.STATUS_CLOSED
+		elif l.startswith("changed session name: "):
+			session.name = l[len("changed session name: "):]
+			self.save_session(session)
+			self.add_session(session)
+			return	None
 		elif l.startswith("xpra: Fatal IO error"):
 			self.serror(None, session, line)
 			return	None
@@ -418,13 +423,13 @@ class	XpraServerUtil(ServerUtilBase):
 		self.watch_existing_log(session)
 
 
-	def grab_session_info(self, session, callback):
-		""" Uses 'xpra info' to populate attributes and options of this session
-			Then calls callback
+	def with_session_info(self, session, callback):
+		""" Passes 'xpra info' data (or None in case of error)
+			to the callback once we have it.
 		"""
 		def err_info(err):
 			self.slog(None, err)
-			callback()
+			callback(None)
 		def got_info(out):
 			self.sdebug(None, out)
 			d = {}
@@ -435,18 +440,30 @@ class	XpraServerUtil(ServerUtilBase):
 				if len(parts)==2:
 					d[parts[0]] = parts[1]
 			self.sdebug("parsed info=%s" % d, out)
-			if "encoding" in d:
-				session.options[ENCODING] = d.get("encoding")
-			session.options[CLIPBOARD] = bool(d.get("clipboard"))
-			session.options[KEYBOARD_SYNC] = bool(d.get("keyboard_sync"))
-			session.name = d.get("session_name", "")
-			session.xpra_version = parse_version_string(d.get("version"))
-			if bool(d.get("shadow")):
-				session.shadowed_display = session.display
-			callback()
+			callback(d)
 		cmd = [self.config.xpra_command, "info", session.display]
 		twisted_exec(cmd, got_info, err_info, log_lifecycle=False)
 
+	def grab_session_info(self, session, callback):
+		""" Populates session attributes from "xpra info",
+			then calls the callback.
+		"""
+		def got_info(d):
+			self.sdebug(None, d)
+			if d:
+				if "encoding" in d:
+					session.options[ENCODING] = d.get("encoding")
+				session.options[CLIPBOARD] = bool(d.get("clipboard"))
+				session.options[KEYBOARD_SYNC] = bool(d.get("keyboard_sync"))
+				session.name = d.get("session_name", "")
+				vstr = d.get("version") or d.get("server.build.version")
+				if vstr:
+					session.xpra_version = parse_version_string(vstr)
+				if bool(d.get("shadow")):
+					session.shadowed_display = session.display
+			callback()
+		self.with_session_info(session, got_info)
+
 	def grab_session_version(self, session, callback):
 		def err_version(err):
 			self.serror(None, err)
@@ -471,6 +488,9 @@ class	XpraServerUtil(ServerUtilBase):
 			current_version = parse_version_string(self.config.xpra_version)
 
 		def with_version(force_upgrade):
+			if not hasattr(session, "xpra_version"):
+				self.serror("failed to get version information from session %s, ignoring it" % session)
+				return
 			self.sdebug("xpra_version=%s" % session.xpra_version, force_upgrade)
 			if not force_upgrade and session.xpra_version>=current_version:
 				self.sdebug("xpra version is up to date")
